
/**
 * Module dependencies.
 */

var express = require('express')
  , models = require('./models')
  , routes = require('./routes')
  , http = require('http')
  , path = require('path')
  , partials = require('express-partials')
  , connect = require('connect')
  , db = require('mongoose')
  ;

var app = express()
  , sessionStore = new connect.session.MemoryStore()
  ;

app.configure('development', function(){
  var config = require('./config/development');
  db.connect(config.db);
  app.use(express.errorHandler());
  app.use(express.cookieParser(config.secret));
  app.set('port', config.port);
});

app.configure('production', function(){
  var config = require('./config/production');
  db.connect(config.db);
  app.use(express.cookieParser(config.secret));
  app.set('port', config.port);
});

app.configure(function(){
  app.set('views', __dirname + '/views');
  app.set('view engine', 'ejs');
  app.use(partials());
  app.use(express.favicon());
  app.use(express.logger('dev'));
  app.use(express.bodyParser());
  app.use(express.methodOverride());
  app.use(express.session({key: 'express.sid', store: sessionStore}));
  app.use(app.router);
  app.use(express.static(path.join(__dirname, 'public')));
});

routes.define(app);

http.createServer(app).listen(app.get('port'), function(){
  console.log("Express server listening on port " + app.get('port'));
});
